
# Version 1: 29 August 2019

# Monte Carlo analysis applied to the estimation of forest carbon stock change, considering 
# aboveground and belowground biomass in living and standing dead trees with diameter greater 
# than or equal to 1.0 inches.

# Developed by: Meredith Amend & Kandice Harper, July 2019


# Details about the calculation method are available in Section 2.1 of the Technical Appendix. 
# The over-arching method used to estimate carbon stock change for this aggregated carbon pool 
# using tree and plot measurements from the FIA Database (USDA Forest Service, 2018) is described 
# in NGHGI (2018), Woodall et al. (2015), and the references therein. The Technical Appendix 
# describes our slight modifications to this method. The equations used for the tree-level biomass 
# calculations are available in Woodall et al. (2011). Domke et al. (2011) describe the updated 
# method for estimating biomass in standing dead trees. The volume coefficients are available in 
# Woodall et al. (2011). The other coefficients needed to calculate living tree biomass are available 
# in the FIA Database (USDA Forest Service, 2018): stump volume coefficients from Raile (1982); 
# specific gravities and bark percentages compiled by Miles & Smith (2009); coefficients for 
# calculating biomass component ratios from Jenkins et al. (2003; 2004); and sapling adjustment 
# factors from Heath et al. (2009). Density reduction factors and structural loss adjustment factors 
# are from Domke et al. (2011). We use information from the following references to derive variances 
# for various model parameters: Forest Products Laboratory (2010) - for specific gravities; 
# Marden et al. (1975) - for bark percentages; Jenkins et al. (2003) - for total aboveground biomass 
# and component ratio coefficients; and Harmon et al. (2011) - for density reduction factors. 
# Variance for the sapling adjustment factor was calculated using data/information from the FIA Database 
# (USDA Forest Service, 2018), Jenkins et al. (2003), Woodall et al. (2011), and Heath et al. (2009). 
# See the Technical Appendix for more information about the derivation of parameter variances.

# This script requires installation of R packages "data.table" (Dowle and Srinivasan, 2019) 
# and "truncnorm" (Mersmann et al., 2018).

# This script calls five additional scripts:
# (1) Read_Data.R
# (2) Read_Data_tab.R
# (3) Timber_Trees.R
# (4) Woodland_Trees.R
# (5) Saplings.R
# NOTE: Some of the code is specific to the eastern Texas input dataset used for this analysis. 
# For example, the forms of the gross volume equations are specific to those applied to the southern 
# United States (see Woodall et al., 2011), and some code modifications are needed in Woodland_Trees.R 
# if the user introduces a dataset that has standing dead woodland trees.

# Below, the user must update the following to run this script:
# (1) The working directory that contains the additional scripts and input datasets.
# (2) n: Number of iterations.
# (3) parGrp: Specifies which parameter group(s) are allowed to vary, while all others are held to their 
# mean values. See Section 2.1 of the Technical Appendix for more information about these model parameters.
# If parGrp=1, only volume coefficients vary.
# If parGrp=2, only wood and bark specific gravities vary.
# If parGrp=3, only bark as a percentage of wood volume parameter varies.
# If parGrp=4, only stump volume coefficients vary.
# If parGrp=5, only values of total aboveground biomass (TAB) calculated following method of Jenkins et al. (2003) vary.
# If parGrp=6, only component ratio coefficients vary.
# If parGrp=7, only sapling adjustment factor varies.
# If parGrp=8, only density reduction factors vary.
# If parGrp=9, only structural loss adjustment factors vary.
# If parGrp=10, all parameter groups 1-9 vary.

# INPUT: The input datasets include tree and plot attributes from FIA ground plots 
# (USDA Forest Service, 2018) and csv files containing mean values and variances for 
# several model parameters. Each tree is linked to each parameter input file using 
# various identifiers (e.g., ID_VOLCOEFF).
# See "README_INPUT_DATASETS.txt" for descriptions of the input datasets.

# OUTPUT: Each execution of this script outputs one csv file of annual plot-level carbon 
# density change (pounds of carbon per acre per year). The output dataset has dimensions: 2236 plots x n+1 
# carbon density change values (1st value is change calculated using mean values of all parameters, 
# values 2 through n+1 are the changes calculated using n iterates of the parameters that are allowed 
# to vary and mean values for the parameters that are not allowed to vary). The order of the plots in 
# the output file corresponds to the order of the plots in the Plot_List.csv input file. Output file name:
# "Annual_carbon_density_change_Grp(parGrp)_n(n).RData," where parGrp and n for the simulation are the 
# values input by the user.





# REFERENCES: 

# Domke, G. M., Woodall, C. W., & Smith, J. E. (2011). Accounting for density reduction and structural loss in standing dead trees: Implications for forest biomass and carbon stock estimates in the United States. Carbon Balance and Management 6, 14, 1–11.

# Dowle, M. & Srinivasan, A. (2019). data.table: Extension of 'data.frame'. (R package version 1.12.2). https://CRAN.R-project.org/package=data.table

# Forest Products Laboratory. (2010). Wood handbook—Wood as an engineering material. (Gen. Tech. Rep. FPL-GTR-190). Madison, WI: U.S. Department of Agriculture, Forest Service, Forest Products Laboratory. 508 p. 

# Harmon, M. E., Woodall, C. W., Fasth, B., Sexton, J., & Yatkov, M. (2011). Differences between standing and downed dead tree wood density reduction factors: A comparison across decay classes and tree species. (Res. Paper NRS-15). Newtown Square, PA: U.S. Department of Agriculture, Forest Service. 44 p.

# Heath, L. S., Hansen, M. H., Smith, J. E., Smith, W. B., & Miles, P. D. (2009). Investigation into calculating tree biomass and carbon in the FIADB using a biomass expansion factor approach. In: McWilliams, W.; Moisen, G.; Czaplewski, R., comps. 2008 Forest Inventory and Analysis (FIA) Symposium; 2008 October 21–23: Park City, UT. Proc. RMRS-P-56CD. Fort Collins, CO: U.S. Department of Agriculture, Forest Service, Rocky Mountain Research Station. 

# Jenkins, J. C., Chojnacky, D. C., Heath, L. S., & Birdsey, R. A. (2003). National-scale biomass estimators for United States tree species. Forest Science, 49(1), 12–35.

# Jenkins, J. C., Chojnacky, D. C., Heath, L. S., & Birdsey, R. A. (2004). Comprehensive database of diameter-based biomass regressions for North American tree species. (Gen. Tech. Rep. NE-219). Newtown Square, PA: U.S. Department of Agriculture, Forest Service. 48 p.

# Marden, R. M., Lothner, D. C., and Kallio, E. (1975). Wood and bark percentages and moisture contents of Minnesota pulpwood species. (Res. Paper NC-114). St. Paul, MN: U.S. Department of Agriculture, Forest Service. 14 p.

# Mersmann, O., Trautmann, H., Steuer, D., & Bornkamp, B. (2018). truncnorm: Truncated Normal Distribution. (R package version 1.0-8). https://CRAN.R-project.org/package=truncnorm

# Miles, P. D. & Smith, W. B. (2009). Specific gravity and other properties of wood and bark for 156 tree species found in North America. (Res. Note NRS-38). Newtown Square, PA: U.S. Department of Agriculture, Forest Service. 39 p.

# Raile, G.K. (1982). Estimating stump volume. (Res. Paper NC-224). St. Paul, MN: U.S. Department of Agriculture, Forest Service. 7 p.

# United States Environmental Protection Agency. (2018). Inventory of U.S. Greenhouse Gas Emissions and Sinks: 1990-2016. Washington, DC. This reference is abbreviated in this script as NGHGI (2018).

# USDA Forest Service (2018). Forest Inventory and Analysis National Program: FIA Data Mart. Washington, DC. Available online at: https://apps.fs.usda.gov/fia/datamart/datamart.html. Accessed 25 August 2018.

# Woodall, C. W., Coulston, J. W., Domke, G. M., Walters, B. F., Wear, D. N., Smith, J. E., Andersen, H.-E., Clough, B. J., Cohen, W. B., Griffith, D. M., Hagen, S. C., Hanou, I. S., Nichols, M. C., Perry, C. H., Russell, M. B., Westfall, J. A., and Wilson, B. T. (2015). The U.S. Forest Carbon Accounting Framework: Stocks and Stock Change, 1990–2016. (Gen. Tech. Rep. NRS-154). Newtown Square, PA: U.S. Department of Agriculture, Forest Service. 60 p.

# Woodall, C. W., Heath, L. S., Domke, G. M., & Nichols, M. C. (2011). Methods and equations for estimating aboveground volume, biomass, and carbon for trees in the U.S. Forest Inventory, 2010. (Gen. Tech. Rep. NRS-88). Newtown Square, PA: U.S. Department of Agriculture, Forest Service. 34 p.







##########################################################################################################################
# DATA IMPORT: !!!!! USER UPDATES REQUIRED (setwd, parGrp, n) !!!!!
# 
##########################################################################################################################

# Call ncessary r packages
library(data.table)
library(truncnorm)

# Set working directory
setwd('')

# Select the desired parameter group
parGrp = 10

# Set number of iterations to perform in the monte carlo 
n = 10000





##########################################################################################################################
# Monte Carlo analysis
# 
##########################################################################################################################

# Read in parameter values and generate random draws as needed for all variables except Jenkins-based total aboveground biomass
source("Read_Data.R")

# Read in list of plot IDs
plots<- read.csv ("Plot_List.csv", header = T)		

# Declare output matrix [plots, n+1 iterations] and temporary output matrix, which is re-initialized before starting calculation on each new plot
Cdens<- array(0, dim=c(nrow(plots),n+1))
if (parGrp==0){
  CdensTemp<- array(0,dim=c(1,1))
} else{
  CdensTemp<- array(0,dim=c(1,n+1))
}

# Declare TPA values
tpaSap<- 74.965282
tpaTree<- 6.018046

# Read in tree data for current period trees and previous period trees
dataCol<- c(NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA)
treesC<- fread("ETX_FRF_TREE_CURRENT.csv", sep=",", colClasses = dataCol)
tabDatC<- read.csv("ETX_FRF_TREE_CURRENT_TAB.csv")
treesP<- fread("ETX_FRF_TREE_PREVIOUS.csv", sep=",", colClasses = dataCol)
tabDatP<- read.csv("ETX_FRF_TREE_PREVIOUS_TAB.csv")	


# Loop for each plot
for (i in 1:nrow(plots)){					# Plot order is determined by the order of the plots as given in the "plots" data frame
  print(c("plot ",i),quote=FALSE)			# Print loop progress
  
  # Loop for each time step: time 1 = current, time 2 = previous
  for(x in 1:2){

    # Read in tree data for current or previous trees
    if (x==1){
      trees<- treesC
      tabDat<- tabDatC
    }else{
      trees<- treesP
      tabDat<- tabDatP
    }
      
    # Isolate plot level TAB data
    tabDatPlot<- tabDat[tabDat[,2]==plots[i,1],]

    # Generate random draws as needed for Jenkins-based total aboveground biomass
    source("Read_Data_tab.R")
 	
    # Separate plot level tree data into timber trees, woodland trees, and saplings - NOTE: some data.tables will be empty
    timber<- as.data.frame(trees[ID_PLOT==plots[i,1] & ID_CATEGORY %in% c(1,5)])
    woodland<- as.data.frame(trees[ID_PLOT==plots[i,1] & ID_CATEGORY %in% c(3,7)])    
    saps<- as.data.frame(trees[ID_PLOT==plots[i,1] & ID_CATEGORY %in% c(2,4,6,8)])

    # Perform live and dead timber tree calculations
    source("Timber_Trees.R")

    # Perform live and dead woodland tree calculations
     source ("Woodland_Trees.R")

    # Perform live and dead sapling calculations (timber and woodland species)
    source ("Saplings.R")


     if (nrow(timber)>0){
           
      # Aggregate tree carbon values (as pounds C/acre) by plot      
      timberC<- aggregate(timberC[,-(1:3)], by=list(timberC$ID_PLOT), FUN=sum)

      # Divide by the plot re-measurement period (REMPER)
      timberC[,-1]<- timberC[,-1]/plots[i,2]  

	  # If parGrp=7, need to expand timberC to have n+1 values (mean and n iterates), where all iterates are identical to the mean value
	  # After this step, for parGrp=1-10, timberC has n+2 columns: plot identifier, value based on mean parameters, n iterates. For parGrp=7, all n iterates are equal to the mean value.
	  if(parGrp==7){
   	 	timberC[,3:(n+2)]<- timberC[,2]
	  }
                
	  # Write values to the output arrays    
      if (x==1){
        CdensTemp[1,]<- CdensTemp[1,] + as.matrix(timberC[1,-1])
      } else {
        CdensTemp[1,]<- CdensTemp[1,] - as.matrix(timberC[1,-1])
      }

	 rm(timberC)

     }		# Code executed only if timber trees exist on this plot
    
    

     if (nrow(woodland)>0){

      # Aggregate tree carbon values (as pounds C/acre) by plot
      woodlandC<- aggregate(woodlandC[,-(1:3)], by=list(woodlandC$ID_PLOT), FUN=sum)
	             
      # Divide by the plot re-measurement period (REMPER)
      woodlandC[,-1]<- woodlandC[,-1]/plots[i,2]

	  # If parGrp=4,7-9, need to expand woodlandC to have n+1 values (mean and n iterates), where all iterates are identical to the mean value	 
	  # After this step, for parGrp=1-10, woodlandC has n+2 columns: plot identifier, value based on mean parameters, n iterates. For parGrp=4,5,7,8,9, all n iterates are equal to the mean value.

	  if(parGrp==4 || parGrp==7 || parGrp==8 || parGrp==9){
   	 	woodlandC[,3:(n+2)]<- woodlandC[,2]
	  }
           
	  # Write values to the output arrays
      if (x==1){
        CdensTemp[1,]<- CdensTemp[1,] + as.matrix(woodlandC[1,-1])
      } else {
        CdensTemp[1,]<- CdensTemp[1,] - as.matrix(woodlandC[1,-1])
      }
      
     rm(woodlandC)    
      
     }		# Code executed only if woodland trees exist on this plot   



     if (nrow(saps)>0){
	 
      # Aggregate sapling carbon values (as pounds C/acre) by plot      
      sapsC<- aggregate(sapsC[,-(1:3)], by=list(sapsC$ID_PLOT), FUN=sum)      

      # Divide by the plot re-measurement period (REMPER)
      sapsC[,-1]<- sapsC[,-1]/plots[i,2]
      
   	  # If parGrp=1-4,8-9, need to expand sapsC to have n+1 values (mean and n iterates), where all iterates are identical to the mean value	 
	  # After this step, for parGrp=1-10, sapsC has n+2 columns: plot identifier, value based on mean parameters, n iterates. For parGrp=1-4,8-9, all n iterates are equal to the mean value.
	  if(parGrp %in% c(1,2,3,4,8,9)){
   	 	sapsC[,3:(n+2)]<- sapsC[,2]
	  }

	  # Write values to the output arrays
      if (x==1){
        CdensTemp[1,]<- CdensTemp[1,] + as.matrix(sapsC[1,-1])
      } else {
        CdensTemp[1,]<- CdensTemp[1,] - as.matrix(sapsC[1,-1])
      }       
      
     rm(sapsC)  
            
    }		# Code executed only if saplings exist on this plot

     
    # Remove variables so old data is not carried over to the next iteration
    rm(timber, woodland, saps)

  } 		# End loop over time steps



  # Store plot-level carbon fluxes in final output array
  Cdens[i,]<- CdensTemp[1,]
  
  # Remake CdensTemp so old values are not carried over to the next plot
  if (parGrp==0){
    CdensTemp<- array(0,dim=c(1,1))
  } else{
    CdensTemp<- array(0,dim=c(1,n+1))
  }
	

}		# End loop over plots    
     
     

# Save the array of plot-level annual C density changes
# Cdens array: dim = # plots x n+1 (value based on mean parameters, n iterates)
filo=paste("Annual_carbon_density_change_Grp",parGrp,"_n",n,".RData",sep="")

save(Cdens, file=filo)


# Clear all variables so they are not carried into next simulation
rm(filo, Cdens, parGrp, n, x, plots, b0, b1, b2, b3, b4, b5, barkBio, barkSPGR, barkVolPct, CdensTemp, dataCol, DIBb1, DIBb2, DOBb1, drf, foliageBio, i, rootBio, sapAdj, slaBark, slaBG, slaBole, slaStump, slaTop, stemBio, tab, tabDat, tabDatC, tabDatP, tpaSap, tpaTree, trees, treesC, treesP, woodSPGR, barkb1, barkb2, folgb1, folgb2, rootb1, rootb2, woodb1, woodb2)

