
# Version 1: 29 August 2019

# This script is called by the main script "Forest_Carbon_MC.R."

###############################################################################################################################
## INPUTS:  Files containing parameter means and variances
## OUTPUTS: Matrices for each parameter:
##          (1) If parGrp = 0, mean values for all parameters
##			(2) If parGrp = 10, n random values for all parameters
##			(3) If parGrp = 1-9, n random values for parameter indicated by parGrp and mean values for all other parameters
###############################################################################################################################

###############################################################################################################################
# Step 1. Read in data from .csv files
###############################################################################################################################

# Read in data files
volDat<- read.csv("VOLCOEFF.csv")
woodSPGRDat<- read.csv("WOOD_SPGR.csv")
barkSPGRDat<- read.csv("BARK_SPGR.csv")
barkVolPctDat<- read.csv("BARK_VOL_PCT.csv")
stumpDat<- read.csv("STUMP.csv")	
ratDat<- read.csv("RATIO_COEFFS.csv")
sapDat<- read.csv("JENKINS_SAP_ADJ.csv")
drfDat<- read.csv("DRF.csv")	
slaDat<- read.csv("SLA.csv")


set.seed(1510.1992*parGrp)

###############################################################################################################################
# Step 2. Create matrices
# The code assumes independence and normal or truncated normal distributions for all variables
###############################################################################################################################

######################### Bole-wood gross cubic-foot volume coefficients
if (parGrp==1 || parGrp==10){
 
  # Generate n normally distributed random variables
  b0<- t(mapply(rnorm,n,volDat[,2],sqrt(volDat[,8])))
  b1<- t(mapply(rnorm,n,volDat[,3],sqrt(volDat[,9])))
  b2<- t(mapply(rnorm,n,volDat[,4],sqrt(volDat[,10])))
  b3<- t(mapply(rnorm,n,volDat[,5],sqrt(volDat[,11])))
  b4<- t(mapply(rnorm,n,volDat[,6],sqrt(volDat[,12])))
  b5<- t(mapply(rnorm,n,volDat[,7],sqrt(volDat[,13])))
      
  # Add lookup IDs and mean values
  b0=cbind(volDat[,1:2],b0)
  b1=cbind(volDat[,c(1,3)],b1)
  b2=cbind(volDat[,c(1,4)],b2)
  b3=cbind(volDat[,c(1,5)],b3)
  b4=cbind(volDat[,c(1,6)],b4)
  b5=cbind(volDat[,c(1,7)],b5)
  
  rm(volDat)

}else{  

  # Set parameters equal to their mean value
  b0<- as.matrix(volDat[,1:2])
  b1<- as.matrix(volDat[,c(1,3)])
  b2<- as.matrix(volDat[,c(1,4)])
  b3<- as.matrix(volDat[,c(1,5)])
  b4<- as.matrix(volDat[,c(1,6)])
  b5<- as.matrix(volDat[,c(1,7)])
  rm(volDat)

}


######################### Specific gravity parameters
if (parGrp==2 || parGrp==10){

  # Generate n normally distributed random variables, truncated at zero
  woodSPGR<- t(mapply(rtruncnorm,n,0,Inf,woodSPGRDat[,2],sqrt(woodSPGRDat[,3])))	
  barkSPGR<- t(mapply(rtruncnorm,n,0,Inf,barkSPGRDat[,2],sqrt(barkSPGRDat[,3])))	
  
  # Add lookup IDs and mean values
  woodSPGR=cbind(woodSPGRDat[,1:2],woodSPGR)
  barkSPGR=cbind(barkSPGRDat[,1:2],barkSPGR)
    
  rm(woodSPGRDat, barkSPGRDat)

}else{

  # Set parameters equal to their mean value
  woodSPGR<- as.matrix(woodSPGRDat[,1:2])
  barkSPGR<- as.matrix(barkSPGRDat[,1:2])
  rm(woodSPGRDat, barkSPGRDat)
  
}


######################### Bark Volume Percent
if (parGrp==3 || parGrp==10){
  
  # Generate n normally distributed random variables, truncated at zero
  barkVolPct<- t(mapply(rtruncnorm,n,0,Inf,barkVolPctDat[,2],sqrt(barkVolPctDat[,3])))
  
  # Add lookup IDs and mean values
  barkVolPct=cbind(barkVolPctDat[,1:2],barkVolPct)
    
  rm(barkVolPctDat)
  
}else{

  # Set parameters equal to their mean value
  barkVolPct<- as.matrix(barkVolPctDat[,1:2])
  rm(barkVolPctDat)
  
}


######################### Raile stump volume coefficients
if (parGrp==4 || parGrp==10){

  # Generate n normally distributed random variables
  DOBb1<- t(mapply(rnorm,n,stumpDat[,2],sqrt(stumpDat[,5])))
  DIBb1<- t(mapply(rnorm,n,stumpDat[,3],sqrt(stumpDat[,6])))
  DIBb2<- t(mapply(rnorm,n,stumpDat[,4],sqrt(stumpDat[,7])))
  
  # Add lookup IDs and mean values
  DOBb1<- cbind(stumpDat[,1:2],DOBb1)
  DIBb1<- cbind(stumpDat[,c(1,3)],DIBb1)
  DIBb2<- cbind(stumpDat[,c(1,4)],DIBb2)
  
  rm(stumpDat)

}else{

  # Set parameters equal to their mean value
  DOBb1<- as.matrix(stumpDat[,1:2])
  DIBb1<- as.matrix(stumpDat[,c(1,3)])
  DIBb2<- as.matrix(stumpDat[,c(1,4)])
  rm(stumpDat)

}


######################### Component ratio coefficients
if (parGrp==6 || parGrp==10){

  # Generate n normally distributed random variables
  woodb1<- t(mapply(rnorm,n,ratDat[,2],sqrt(ratDat[,10])))
  woodb2<- t(mapply(rnorm,n,ratDat[,3],sqrt(ratDat[,11])))
  barkb1<- t(mapply(rnorm,n,ratDat[,4],sqrt(ratDat[,12])))
  barkb2<- t(mapply(rnorm,n,ratDat[,5],sqrt(ratDat[,13])))
  folgb1<- t(mapply(rnorm,n,ratDat[,6],sqrt(ratDat[,14])))
  folgb2<- t(mapply(rnorm,n,ratDat[,7],sqrt(ratDat[,15])))
  rootb1<- t(mapply(rnorm,n,ratDat[,8],sqrt(ratDat[,16])))
  rootb2<- t(mapply(rnorm,n,ratDat[,9],sqrt(ratDat[,17])))
  
  # Add lookup IDs and mean values
  woodb1<- cbind(ratDat[,1:2],woodb1)
  woodb2<- cbind(ratDat[,c(1,3)],woodb2)
  barkb1<- cbind(ratDat[,c(1,4)],barkb1)
  barkb2<- cbind(ratDat[,c(1,5)],barkb2)
  folgb1<- cbind(ratDat[,c(1,6)],folgb1)
  folgb2<- cbind(ratDat[,c(1,7)],folgb2)
  rootb1<- cbind(ratDat[,c(1,8)],rootb1)
  rootb2<- cbind(ratDat[,c(1,9)],rootb2)
  
  rm(ratDat)

}else{

  # Set parameters equal to their mean value
  woodb1<- as.matrix(ratDat[,1:2])
  woodb2<- as.matrix(ratDat[,c(1,3)])
  barkb1<- as.matrix(ratDat[,c(1,4)])
  barkb2<- as.matrix(ratDat[,c(1,5)])
  folgb1<- as.matrix(ratDat[,c(1,6)])
  folgb2<- as.matrix(ratDat[,c(1,7)])
  rootb1<- as.matrix(ratDat[,c(1,8)])
  rootb2<- as.matrix(ratDat[,c(1,9)])
  rm(ratDat)

}


######################### Jenkins sapling adjustment
if (parGrp==7 || parGrp==10){

  # Generate n normally distributed random variables, truncated at zero
  sapAdj<- t(mapply(rtruncnorm,n,0,Inf,sapDat[,2],sqrt(sapDat[,3])))
  
  # Add lookup IDs and mean values
  sapAdj=cbind(sapDat[,1:2],sapAdj)
  
  rm(sapDat)

}else{
	
  # Set parameters equal to their mean value
  sapAdj<- as.matrix(sapDat[,1:2])
  rm(sapDat)
  
}


######################### DRF
if (parGrp==8 || parGrp==10){

  # Generate n normally distributed random variables, truncated at zero and one
  drf<- t(mapply(rtruncnorm,n,0,1,drfDat[,2],sqrt(drfDat[,3])))
  
  # Add lookup IDs and mean values
  drf=cbind(drfDat[,1:2],drf)
  
  rm(drfDat)

}else{
    
  # Set parameters equal to their mean value
  drf<- as.matrix(drfDat[,1:2])
  rm(drfDat)
  
}


######################### SLA
if (parGrp==9 || parGrp==10){

  # Generate n normally distributed random variables, truncated at zero and one
  slaTop<- t(mapply(rtruncnorm,n,-0.0001,1,slaDat[,2],sqrt(slaDat[,7])))
  slaBark<- t(mapply(rtruncnorm,n,-0.0001,1,slaDat[,3],sqrt(slaDat[,8])))
  slaBole<- t(mapply(rtruncnorm,n,0,1,slaDat[,4],sqrt(slaDat[,9])))
  slaStump<- t(mapply(rtruncnorm,n,0,1,slaDat[,5],sqrt(slaDat[,10])))
  slaBG<- t(mapply(rtruncnorm,n,0,1,slaDat[,6],sqrt(slaDat[,11])))
  
  # Add lookup IDs and mean values
  slaTop=cbind(slaDat[,1:2],slaTop)
  slaBark=cbind(slaDat[,c(1,3)],slaBark)
  slaBole=cbind(slaDat[,c(1,4)],slaBole)
  slaStump=cbind(slaDat[,c(1,5)],slaStump)
  slaBG=cbind(slaDat[,c(1,6)],slaBG)

  rm(slaDat)

}else{
  
  # Set parameters equal to their mean value
  slaTop<- as.matrix(slaDat[,1:2])
  slaBark<- as.matrix(slaDat[,c(1,3)])
  slaBole<- as.matrix(slaDat[,c(1,4)])
  slaStump<- as.matrix(slaDat[,c(1,5)])
  slaBG<- as.matrix(slaDat[,c(1,6)])
  rm(slaDat)

}


