
# Version 1: 29 August 2019

# This script is called by the main script "Forest_Carbon_MC.R."

###############################################################################################################
## FUNCTION NAME: Timber_Trees.R
## INPUTS: Data for timber trees (with diameter greater than or equal to 5.0 inches) on plot being analyzed
## OUTPUTS: Pounds of carbon per acre estimates for live and dead timber trees on this plot
###############################################################################################################

# If a particular plot has no timber trees, skip it
if (nrow(timber)>0){

  #####################################################
  # Step 1. Calculate bole biomass - DRYBIO_BOLE
  #####################################################
  
  # Step 1a. Calculate bole-wood gross cubic-foot volume
  VOLCFGRS<- cbind(timber[,c(1:3,5:7)], VOLCFGRS=timber$DIA^2*b1[match(timber$ID_VOLCOEFF,b1[,1]),-1]*timber$HT+b0[match(timber$ID_VOLCOEFF,b0[,1]),-1])
   
  # Step 1b. Calculate bole-wood sound cubic-foot volume by subtracting rotten and missing parts (cull) from gross volume
  VOLCFSND<- cbind(VOLCFGRS[,1:6],VOLCFSND=VOLCFGRS[,-(1:6)]*(1-timber$CULL_ADJ/100))
    
  # Step 1c. Calculate bole biomass
  DRYBIO_BOLE<- cbind(VOLCFSND[,1:3], DRYBIO_BOLE=VOLCFSND[,-(1:6)]*62.4*(woodSPGR[match(VOLCFSND[,4],woodSPGR[,1]),-1]+barkSPGR[match(VOLCFSND[,5],barkSPGR[,1]),-1]*barkVolPct[match(VOLCFSND[,6],barkVolPct[,1]),-1]*0.01))
    
  # Adjustment for dead trees
  drfBole<- cbind(timber$ID_TREE,drf[match(timber$ID_DRF, drf[,1]),-1]*slaBole[match(timber$ID_SLA,slaBole[,1]),-1])

  drfBark<- cbind(timber$ID_TREE, drf[match(timber$ID_DRF, drf[,1]),-1]*slaBark[match(timber$ID_SLA,slaBark[,1]),-1])
    
  DRYBIO_BOLE_DEAD<- cbind(VOLCFSND[,1:3], DRYBIO_BOLE=VOLCFSND[,-(1:6)]*62.4*(woodSPGR[match(VOLCFSND[,4],woodSPGR[,1]),-1]*drfBole[,-1]+barkSPGR[match(VOLCFSND[,5],barkSPGR[,1]),-1]*barkVolPct[match(VOLCFSND[,6],barkVolPct[,1]),-1]*0.01*drfBark[,-1]))

 # If parGrp=8,9:
 # DRYBIO_BOLE (so far) has 4 columns: ID_TREE, ID_PLOT, ID_CATEGORY, value based on means; row for each tree (living and dead, but dead tree biomass has not been adjusted)
 # DRYBIO_BOLE_DEAD has n+4 columns: ID_TREE, ID_PLOT, ID_CATEGORY, value based on means, n iterates; row for each tree, but values are NA for living trees
 # Cannot simply bind these together; must replicate the DRYBIO_BOLE values for the living trees first
 # Must also fix the column labels of the n iterates for the DRYBIO_BOLE_DEAD data frame
 if(parGrp==8 || parGrp==9){
	DRYBIO_BOLE[,5:(n+4)]<- DRYBIO_BOLE[,4] 
 } 
 colnames(DRYBIO_BOLE_DEAD)<- colnames(DRYBIO_BOLE)

  DRYBIO_BOLE<- rbind(DRYBIO_BOLE[DRYBIO_BOLE$ID_CATEGORY!=5,],DRYBIO_BOLE_DEAD[DRYBIO_BOLE_DEAD$ID_CATEGORY==5,])
  DRYBIO_BOLE<- DRYBIO_BOLE[order(DRYBIO_BOLE$ID_TREE),]
    
  rm(VOLCFGRS,VOLCFSND,DRYBIO_BOLE_DEAD,drfBark,drfBole)
  

 

  ######################################################
  # Step 2. Calculate Jenkins biomass by component & MST
  ######################################################
    
  # Step 2a. Calculate biomass ratios
  ratioStem<- cbind(timber[,1:2],ratioStem=exp(woodb1[match(timber$ID_ratio_coeff,woodb1[,1]),-1]+(woodb2[match(timber$ID_ratio_coeff,woodb2[,1]),-1]/(timber$DIA*2.54))))
  ratioRoot<- cbind(timber[,1:2],ratioRoot=exp(rootb1[match(timber$ID_ratio_coeff,rootb1[,1]),-1]+(rootb2[match(timber$ID_ratio_coeff,rootb2[,1]),-1]/(timber$DIA*2.54))))
  ratioFoliage<- cbind(timber[,1:2],ratioFoliage=exp(folgb1[match(timber$ID_ratio_coeff,folgb1[,1]),-1]+(folgb2[match(timber$ID_ratio_coeff,folgb2[,1]),-1]/(timber$DIA*2.54))))
  ratioBark<- cbind(timber[,1:2],ratioBark=exp(barkb1[match(timber$ID_ratio_coeff,barkb1[,1]),-1]+(barkb2[match(timber$ID_ratio_coeff,barkb2[,1]),-1]/(timber$DIA*2.54))))

  # Institute threshold check
  ratioStem<- as.matrix(ratioStem[,-c(1:2)])
  ratioBark<- as.matrix(ratioBark[,-c(1:2)])
  ratioFoliage<- as.matrix(ratioFoliage[,-c(1:2)])

  # if the sum of the aboveground ratios exceeds 0.9 or is less than 0.6 then normalize to those thresholds
  check <- ratioStem+ratioFoliage+ratioBark

  check1<- check>0.9
  ratioStem<- ifelse(check1,ratioStem*0.9/check,ratioStem)
  ratioFoliage<- ifelse(check1,ratioFoliage*0.9/check,ratioFoliage)
  ratioBark<- ifelse(check1,ratioBark*0.9/check,ratioBark)
      
  check2<- check<0.6
  ratioStem<- ifelse(check2,ratioStem*0.6/check,ratioStem)				
  ratioFoliage<- ifelse(check2,ratioFoliage*0.6/check,ratioFoliage)
  ratioBark<- ifelse(check2,ratioBark*0.6/check,ratioBark)
 
  # Add tree and plot IDs
  ratioStem<- cbind(timber[,1:2],ratioStem)
  ratioFoliage<- cbind(timber[,1:2],ratioFoliage)
  ratioBark<- cbind(timber[,1:2],ratioBark)

  rm(check,check1,check2)


  # Step 2b. Separate TAB into its components

  stemBio<- as.data.frame(ratioStem)
  stemBio<- cbind(stemBio[,1:2],stemBio[,-(1:2)]*tab[match(stemBio[,1],tab[,1]),-(1:2)])  
    
  rootBio<- as.data.frame(ratioRoot)
  rootBio<- cbind(rootBio[,1:2],rootBio[,-(1:2)]*tab[match(rootBio[,1],tab[,1]),-(1:2)])
    
  foliageBio<- as.data.frame(ratioFoliage)
  foliageBio<- cbind(foliageBio[,1:2],foliageBio[,-(1:2)]*tab[match(foliageBio[,1],tab[,1]),-(1:2)])

  barkBio<- as.data.frame(ratioBark)
  barkBio<- cbind(barkBio[,1:2],barkBio[,-(1:2)]*tab[match(barkBio[,1],tab[,1]),-(1:2)])

  rm(ratioStem, ratioRoot, ratioFoliage, ratioBark)



  # Calculate MST  
  stemBio<- stemBio[order(stemBio$ID_TREE),]
  barkBio<- barkBio[order(barkBio$ID_TREE),]

  MST<- stemBio
  MST<- cbind(MST[,1:2], MST[,-(1:2)]+barkBio[,-(1:2)])
  
  

 
  
  #####################################################
  # Step 3. Calculate CRM adjustment factor - CRMadj
  #####################################################
  
  # Step 3a. Calculate CRM adjustment factor

  CRMadj<- DRYBIO_BOLE
  CRMadj<- cbind(CRMadj[,1:3],CRMadj[,-(1:3)]/MST[match(DRYBIO_BOLE[,1],MST[,1]),-(1:2)])





  ########################################################
  # Step 4. Calculate stump biomass following Raile (1982)
  # and apply CRM adjustment factor - stump, DRYBIO_STUMP
  ########################################################

  stumpFactor<- cbind(timber[,c(1:3,5:6,8)],pi*timber$DIA^2/576)

  ## Step 4a. Calculate stump volume outside

  # volume outside 1ft    
  raileOut1ft<- cbind(DOBb1[,1],(1-DOBb1[,-1])^2+11*DOBb1[,-1]*(1-DOBb1[,-1])*log(2)-15.125*DOBb1[,-1]^2) 
  stumpOut1ft<- cbind(stumpFactor[,1:6], (stumpFactor[,-(1:6)]*raileOut1ft[match(stumpFactor[,6],raileOut1ft[,1]),-1]))
 
  # volume outside 0ft
  stumpOut0ft<- cbind(stumpFactor[,1:6], (stumpFactor[,-(1:6)]*-30.25*DOBb1[match(stumpFactor[,6],DOBb1[,1]),-1]^2))
   
  #volume outside
  stumpOut<- cbind(stumpFactor[,1:6], stumpOut1ft[,-(1:6)]-stumpOut0ft[,-(1:6)])
  
  rm(raileOut1ft,stumpOut1ft,stumpOut0ft)
  
    
  ## Step 4b. Calculate stump volume inside

  # volume inside 1ft
  raileIn1ft<- cbind(DIBb1[,1],(DIBb1[,-1]-DIBb2[,-1])^2+11*DIBb2[,-1]*(DIBb1[,-1]-DIBb2[,-1])*log(2)-15.125*DIBb2[,-1]^2)
  stumpIn1ft<- cbind(stumpFactor[,1:6], (stumpFactor[,-(1:6)]*raileIn1ft[match(stumpFactor[,6],raileIn1ft[,1]),-1]))
  
  # volume inside 0ft
  stumpIn0ft<- cbind(stumpFactor[,1:6], (stumpFactor[,-(1:6)]*-30.25*DIBb2[match(stumpFactor[,6],DIBb2[,1]),-1]^2))
  
  # volume inside
  stumpIn<- cbind(stumpFactor[,1:6], stumpIn1ft[,-(1:6)]-stumpIn0ft[,-(1:6)])
  
  rm(raileIn1ft,stumpIn1ft,stumpIn0ft,stumpFactor)
  
  
  ## Step 4c. Calculate stump biomass

  stumpWood<- cbind(stumpIn[,1:6], stumpIn[,-(1:6)]*woodSPGR[match(stumpIn[,4],woodSPGR[,1]),-1]*62.4)
  stumpBark<- cbind(stumpIn[,1:6], (stumpOut[,-(1:6)]-stumpIn[,-(1:6)])*barkSPGR[match(stumpIn[,5],barkSPGR[,1]),-1]*62.4)
  stump<- cbind(stumpWood[,1:3],stumpWood[,-(1:6)]+stumpBark[,-(1:6)])
  
  rm(stumpIn,stumpOut,stumpWood,stumpBark)
 

  ## Step 4d. Calculate CRM-derived stump biomass
  #DRYBIO_STUMP<- cbind(stump[,1:3],StumpBio=stump[,-(1:3)]*CRMadj[,-(1:3)])
  DRYBIO_STUMP<- cbind(stump[,1:3],StumpBio=stump[,-(1:3)]*CRMadj[match(stump[,1],CRMadj[,1]),-(1:3)])
  
 
  ## Step 4e. Adjustment for dead trees
  slaStumpTimber<- cbind(timber$ID_TREE,slaStump[match(timber$ID_SLA, slaStump[,1]),-1])
  DRYBIO_STUMP_DEAD<- cbind(DRYBIO_STUMP[,1:3], DRYBIO_STUMP[,-(1:3)]*slaStumpTimber[match(DRYBIO_STUMP[,1],slaStumpTimber[,1]),-1])
  colnames(DRYBIO_STUMP_DEAD)<- colnames(DRYBIO_STUMP)

  DRYBIO_STUMP<- rbind(DRYBIO_STUMP[DRYBIO_STUMP$ID_CATEGORY!=5,],DRYBIO_STUMP_DEAD[DRYBIO_STUMP_DEAD$ID_CATEGORY==5,])
  DRYBIO_STUMP<- DRYBIO_STUMP[order(DRYBIO_STUMP$ID_TREE),]

  rm(slaStumpTimber,DRYBIO_STUMP_DEAD)
  
  


  
  #####################################################
  # Step 5. Calculate top and limb biomass - DRYBIO_TOP
  #####################################################
 
  DRYBIO_TOP<- cbind(timber[,c(1:3,13)], TopBio=(tab[match(timber$ID_TREE,tab[,1]),-(1:2)]-MST[match(timber$ID_TREE,MST[,1]),-(1:2)]-stump[match(timber$ID_TREE,stump[,1]),-(1:3)]-foliageBio[match(timber$ID_TREE,foliageBio[,1]),-(1:2)])*CRMadj[match(timber$ID_TREE,CRMadj[,1]),-(1:3)])
  
  # Step 5b. Adjustment for dead trees	
  DRYBIO_TOP_DEAD<- cbind(DRYBIO_TOP[,1:3], DRYBIO_TOP[,-(1:4)]*slaTop[match(DRYBIO_TOP[,4],slaTop[,1]),-1])
  DRYBIO_TOP<- DRYBIO_TOP[,-4]
  colnames(DRYBIO_TOP_DEAD)<- colnames(DRYBIO_TOP)
  
  DRYBIO_TOP<- rbind(DRYBIO_TOP[DRYBIO_TOP$ID_CATEGORY!=5,],DRYBIO_TOP_DEAD[DRYBIO_TOP_DEAD$ID_CATEGORY==5,])
  DRYBIO_TOP<- DRYBIO_TOP[order(DRYBIO_TOP$ID_TREE),]
  
  rm(MST,stump, DRYBIO_TOP_DEAD)
  

  

  
  #####################################################
  # Step 6. Calculate above- and below-ground carbon
  #####################################################
  
  # Step 6a. Calculate above- and below-ground carbon  
  timber <- timber[order(timber$ID_TREE),]
  timberAGC<- cbind(timber[,1:3],AGC=0.5*(DRYBIO_BOLE[,-(1:3)]+DRYBIO_TOP[,-(1:3)]+DRYBIO_STUMP[,-(1:3)]))
  timberBGC<- cbind(timber[,1:3],BGC=0.5*CRMadj[match(timber$ID_TREE,CRMadj[,1]),-(1:3)]*rootBio[match(timber$ID_TREE,rootBio[,1]),-(1:2)])
 
  # Step 6b. Adjustment for dead trees
  slaBGTimber<- cbind(timber$ID_TREE,slaBG[match(timber$ID_SLA, slaBG[,1]),-1])
  timberBGC_DEAD<- cbind(timberBGC[,1:3], timberBGC[,-(1:3)]*slaBGTimber[,-1])
  colnames(timberBGC_DEAD)<- colnames(timberBGC)
 
  timberBGC<- rbind(timberBGC[timberBGC$ID_CATEGORY!=5,],timberBGC_DEAD[timberBGC_DEAD$ID_CATEGORY==5,])
  timberBGC<- timberBGC[order(timberBGC$ID_TREE),]
    
  # Step 6c. combine AGC and BGC and multiply by applicable TPA_UNADJ value to convert to pounds C per acre represented by that tree
  timberC<- cbind(timberAGC[,1:3],timberAGC[,-(1:3)]+timberBGC[,-(1:3)])
  timberC[,-(1:3)]<- timberC[,-(1:3)]*tpaTree

  rm(slaBGTimber, timberBGC_DEAD, timberAGC, timberBGC, DRYBIO_BOLE, DRYBIO_TOP, DRYBIO_STUMP, CRMadj)


}	# Perform calculation only if plot has timber trees





