

# Version 1: 29 August 2019


# Monte Carlo analysis to estimate 95% confidence interval and model uncertainty associated 
# with litter carbon stock change. Additional details about the calculation method are 
# available in Section 2.2 of the Technical Appendix.


# INPUT DATA INCLUDES: 
# (1) Predominant forest type in "previous" period for forest remaining forest (FRF) area on each 
# FRF-containing plot in eastern Texas, as determined from data in FIA Database (USDA Forest Service, 2018). 
# Forest types are mapped to the four forest types in Table 1 of Domke et al. (2016). The stratum 
# to which each of these plots belongs and the total FRF area per stratum were also determined using FIA data.
# (2) Mean litter carbon stocks for southern United States by forest type from Table 1 of Domke et al. (2016).
# (3) Modeling mean-squared error for litter carbon from NGHGI (2018), Annex 3, sub-section 3.13.
# (4) National-mean litter carbon sequestration rate for FRF for 2016, based on data in NGHGI (2018).


# OUTPUT PRINTED TO SCREEN INCLUDES:
# Model-based variance for the eastern Texas analysis region
# Mean litter carbon stock change for eastern Texas
# 95% confidence interval for eastern Texas litter carbon stock change
# 95% confidence interval for United States litter carbon stock change
# Contribution to uncertainty from litter modeling error



# PROGRAM NOTES:

# This script requires installation of the R package "mvtnorm" (Genz et al., 2019).

# Forest type key for variable "predom_fortype_previous" in input file PREDOM_FOREST_TYPE.csv:
# 1 - Hardwood
# 2 - Pine
# 3 - Mixed conifer
# 4 - Nonstocked
# Forest types correspond to the set of four forest types in Table 1 of Domke et al., 2016.

# ID_STRATUM key for input file PREDOM_FOREST_TYPE.csv (based on estimation unit and canopy cover bin):
# 1 - STRATUM_CN = 540237787126144 indicates NFS 0-98% canopy cover (NFS bin 1)
# 2 - STRATUM_CN = 540237788126144 indicates NFS 99-100% canopy cover (NFS bin 2)
# 3 - STRATUM_CN = 540237779126144 indicates SE 0-10% canopy cover (SE bin 1)
# 4 - STRATUM_CN = 540237780126144 indicates SE 11-47% canopy cover (SE bin 2)
# 5 - STRATUM_CN = 540237781126144 indicates SE 48-84% canopy cover (SE bin 3)
# 6 - STRATUM_CN = 540237782126144 indicates SE 85-100% canopy cover (SE bin 4)
# 7 - STRATUM_CN = 540237783126144 indicates NE 0-47% canopy cover (NE bin 1)
# 8 - STRATUM_CN = 540237785126144 indicates NE 48-84% canopy cover (NE bin 2)
# 9 - STRATUM_CN = 540237786126144 indicates NE 85-100% canopy cover (NE bin 3)
# NFS = National Forest Service land; NE = Northeast Texas, excluding NFS land; SE = Southeast Texas, excluding NFS land
# STRATUM_CN corresponds to identifier used in FIA Database (USDA Forest Service, 2018).

# Area (ha) of FRF in each stratum (calculated using data from FIA Database - USDA Forest Service, 2018):
# STRATUM 1: 88,317
# STRATUM 2: 161,101
# STRATUM 3: 18,625
# STRATUM 4: 211,945
# STRATUM 5: 445,847
# STRATUM 6: 1,783,418
# STRATUM 7: 144,158
# STRATUM 8: 450,279
# STRATUM 9: 1,449,369

# Applies normal distribution for the litter carbon stocks.

# Mean litter carbon stocks for southern United States by forest type from Table 1 of Domke et al. (2016):
# Nonstocked: 5.17 metric tons C/ha x (44 metric tons CO2/12 metric tons C) = 18.96 metric tons CO2/ha
# Pine: 7.48 metric tons C/ha x (44 metric tons CO2/12 metric tons C) = 27.43 metric tons CO2/ha
# Hardwood: 7.86 metric tons C/ha x (44 metric tons CO2/12 metric tons C) = 28.82 metric tons CO2/ha
# Mixed conifer: 15.55 metric tons C/ha x (44 metric tons CO2/12 metric tons C) = 57.02 metric tons CO2/ha

# From NGHGI (2018), Annex 3, sub-section 3.13, page A-392:
# Modeling mean-squared error for litter carbon = 78.0 (metric tons C/ha)^2 x (44 metric tons CO2/12 metric tons C)^2 
# = 1050 (metric tons CO2/ha)^2
# This is used as the variance for the litter carbon stock for all forest types.

# National-mean litter carbon sequestration rate for FRF for 2016, based on data in NGHGI (2018):
# (1) 16.1 MMT CO2/y is the national carbon sequestration for litter on FRF for 2016 (Table 6.10 of NGHGI, 2018)
# (2) 272,260,000 ha is the national FRF area in 2016 (Table 6.12 of NGHGI, 2018)
# Divide (1) by (2) to get national-mean litter carbon sequestration rate for FRF 
# = (16,100,000 metric tons CO2/y) / (272,260,000 ha) = 0.06 metric tons CO2/ha/y

# The mean litter carbon stock change output from this script should be around 285,000 metric tons CO2/y (sequestered) 
# based on: (1) there are 4,753,058 ha FRF in eastern Texas (calculated using data from FIA Database - USDA Forest Service, 2018) 
# and (2) the national-mean sequestration rate for FRF is 0.06 metric tons CO2/ha/y.

# Equations 1-3 of Ogle et al. (2010) are applied in this script. Equation 1 is used to calculate the 
# annual change in litter carbon stock for each iterate. Equation 2 is used to calculate the mean annual 
# change in litter carbon stock over all iterates. The 95% confidence interval for eastern Texas is 
# estimated using these results. Equation 3 of Ogle et al. (2010) is used to calculate the variance 
# associated with model uncertainty. The sampling error is not calculated as all plots are forced to 
# have the national mean sequestration rate. The model variance is used to combine uncertainties for 
# the forest litter, soil, and biomass pools (see Section 2.1 of the Technical Appendix).





# REFERENCES:

# Domke, G. M., Perry, C. H., Walters, B. F., Woodall, C. W., Russell, M. B., and Smith, J. E. (2016). Estimating litter carbon stocks on forest land in the United States. Science of the Total Environment 557-558, 469-478, doi: 10.1016/j.scitotenv.2016.03.090.

# Genz, A., Bretz, F., Miwa, T., Mi, X., Leisch, F., Scheipl, F., Bornkamp, B., Maechler, M., & Hothorn, T., (2019). mvtnorm: Multivariate Normal and t Distributions. (R package version 1.0-10). http://CRAN.R-project.org/package=mvtnorm

# Ogle, S. M., Breidt, F. J., Easter, M., Williams, S., Killian, K., and Paustian, K. (2010). Scale and uncertainty in modeled soil organic carbon stock changes for US croplands using a process-based model. Global Change Biology 16, 810-822, doi: 10.1111/j.1365-2486.2009.01951.x.

# United States Environmental Protection Agency. (2018). Inventory of U.S. Greenhouse Gas Emissions and Sinks: 1990-2016. Washington, DC. This reference is abbreviated in this script as NGHGI (2018).

# USDA Forest Service (2018). Forest Inventory and Analysis National Program: FIA Data Mart. Washington, DC. Available online at: https://apps.fs.usda.gov/fia/datamart/datamart.html. Accessed 25 August 2018.







################################################################################################
### Input data ###
################################################################################################

library(mvtnorm)

### Input file
FOREST_INPUT_filename <- "PREDOM_FOREST_TYPE.csv"		# Predominant forest type for FRF area on the plot, for each eastern Texas plot associated with EVALID 481723 that has at least one geographic area that is FRF. Predominant forest type refers to the forest type of the FRF area in the previous measurement period. The condensed set of four forest types correspond to those for the southern United States in Table 1 of Domke et al., 2016. Key: 1 - Hardwood; 2 - Pine; 3 - Mixed conifer; 4 - Nonstocked. For each plot, input file includes variable ID_STRATUM (possible values 1-9) that specifies to which stratum the plot belongs. See stratum key above. Columns in input file data frame: plot (PLT_CN from FIA Database), predom_fortype_previous, ID_STRATUM. 

FOREST_INPUT <- read.table(FOREST_INPUT_filename,header=TRUE,sep=",",stringsAsFactors=FALSE)
num_plots <- length(FOREST_INPUT$plot)
rm(FOREST_INPUT_filename)


### Define parameters
n <- 10000											# Number of draws
stock_variance <- 1050 								# Units [metric tons CO2/ha]^2; this is the modeling mean-squared error for litter carbon from NGHGI (2018), Annex 3.13
cov_as_frac_of_var <- 0.999							# Covariance between previous period and next period (previous period + 1 year) litter carbon stocks is set as a fraction of the stock variance
stock_covariance <- cov_as_frac_of_var*stock_variance
sigma <- matrix(c(stock_variance,stock_covariance,stock_covariance,stock_variance), nrow=2, ncol=2)			# Does not vary by plot
US_FLUX_MMTCO2y <- 16.1								# MMT CO2/y litter carbon stock change for United States for FRF for 2016, from Table 6-10 of NGHGI (2018); this is a sequestration
FRF_HA_STRATUM <- c(88317, 161101, 18625, 211945, 445847, 1783418, 144158, 450279, 1449369)					# Area (ha) of FRF in each stratum, in order of ID_STRATUM 1, 2, ..., 9

print(c("n = ",n),quote=FALSE)
print(c("covariance = ",cov_as_frac_of_var," x variance"),quote=FALSE)
rm(stock_variance, cov_as_frac_of_var, stock_covariance)




################################################################################################
### Calculate expansion factors for plots by stratum ###
################################################################################################

# Expansion factor for a given stratum indicates the # of hectares of FRF that are represented by each FRF-containing plot in that stratum

### Calculate number of FRF-containing plots in each stratum
num_plots_strat <- vector(mode="numeric",length=9)
num_plots_strat[1] <- length(which(FOREST_INPUT$ID_STRATUM==1))
num_plots_strat[2] <- length(which(FOREST_INPUT$ID_STRATUM==2))
num_plots_strat[3] <- length(which(FOREST_INPUT$ID_STRATUM==3))
num_plots_strat[4] <- length(which(FOREST_INPUT$ID_STRATUM==4))
num_plots_strat[5] <- length(which(FOREST_INPUT$ID_STRATUM==5))
num_plots_strat[6] <- length(which(FOREST_INPUT$ID_STRATUM==6))
num_plots_strat[7] <- length(which(FOREST_INPUT$ID_STRATUM==7))
num_plots_strat[8] <- length(which(FOREST_INPUT$ID_STRATUM==8))
num_plots_strat[9] <- length(which(FOREST_INPUT$ID_STRATUM==9))


### For each stratum, calculate expansion factor by dividing # of ha of FRF in that stratum by # of FRF-containing plots in that stratum
strata_expns_ha <- FRF_HA_STRATUM/num_plots_strat		# In order of ID_STRATUM 1, 2, ..., 9; # ha represented by each plot in the indicated stratum	
rm(FRF_HA_STRATUM, num_plots_strat)




################################################################################################
### Plot-level calculations ###
################################################################################################

### For previous period, assign mean litter carbon stock (metric tons CO2/ha) based on forest type	

litter_mean_previous <- vector(mode="numeric",length=num_plots)
litter_mean_previous[which(FOREST_INPUT$predom_fortype_previous==1)] <- 28.82			# Hardwood 
litter_mean_previous[which(FOREST_INPUT$predom_fortype_previous==2)] <- 27.43			# Pine
litter_mean_previous[which(FOREST_INPUT$predom_fortype_previous==3)] <- 57.02			# Mixed conifer
litter_mean_previous[which(FOREST_INPUT$predom_fortype_previous==4)] <- 18.96			# Nonstocked



### For next period (previous period + 1 year), assign mean litter carbon stock (metric tons CO2/ha) that is equal to the previous period stock plus 0.06 metric tons CO2/ha. The result is that, assuming a 1-year time step, the sequestration rate for each plot will be identical to the national-average sequestration rate of 0.06 metric tons CO2/ha/y.

litter_mean_next <- vector(mode="numeric",length=num_plots)
litter_mean_next[which(FOREST_INPUT$predom_fortype_previous==1)] <- 28.88			# Hardwood
litter_mean_next[which(FOREST_INPUT$predom_fortype_previous==2)] <- 27.49			# Pine
litter_mean_next[which(FOREST_INPUT$predom_fortype_previous==3)] <- 57.08			# Mixed conifer
litter_mean_next[which(FOREST_INPUT$predom_fortype_previous==4)] <- 19.02			# Nonstocked


FOREST_INPUT$litter_mean_previous <- litter_mean_previous
FOREST_INPUT$litter_mean_next <- litter_mean_next
rm(litter_mean_previous, litter_mean_next)



### For each plot:
# (1) Apply rmvnorm given prescribed means. Result is n values for previous period litter carbon stock and n values for next period (previous period + 1 year) litter carbon stock.
# (2) For each of the n pairs, take next period stock minus previous period stock to get n annual stock change (flux) values.

# So far, have FOREST_INPUT columns: plot, predom_fortype_previous, ID_STRATUM, litter_mean_previous, litter_mean_next

# Make array for storing the output with dimensions: # plots x n
FLUX_plotBYn <- array(NA, dim=c(num_plots, n))


set.seed(1510.1992)

for(i in 1:num_plots){	
	means=c(FOREST_INPUT$litter_mean_previous[i], FOREST_INPUT$litter_mean_next[i])		# Vector of means to be used as input for the rmvnorm function for this plot
	plot_stocks <- rmvnorm(n, means, sigma)					# Result: array with dims = n x 2 (1 - previous period stock, 2 - next period stock)
	n_flux <- (plot_stocks[,2]-plot_stocks[,1])				# Vector with dim = n, flux units: metric tons CO2/ha/y
	FLUX_plotBYn[i,] <- n_flux								# Assign n_flux for this plot to FLUX_plotBYn array, flux units: metric tons CO2/ha/y
	rm(means, plot_stocks, n_flux)
}
rm(i, sigma, num_plots)


if(any(is.na(FLUX_plotBYn))){
	print(c("ERROR: Missing values in FLUX_plotBYn"),quote=FALSE)	
}






################################################################################################
### Calculate theta for each iteration (equation 1 of Ogle et al., 2010) ###
################################################################################################

# For the modeling uncertainty calculation, notation follows that of equations 1-3 in Ogle et al. (2010).
# theta_i: change in litter carbon stock for iterate i
# omega_k: area weight assigned to each plot k
# deltaC_ki: change in litter carbon stock for the kth plot for iterate i

# theta_i = sum over each plot k of (omega_k x deltaC_ki) 

# Input data:
# FLUX_plotBYn: array of fluxes (metric tons CO2/ha/y), dim = # plots x n
# FOREST_INPUT columns: plot, predom_fortype_previous, ID_STRATUM, litter_mean_previous, litter_mean_next
# strata_expns_ha: # ha represented by each plot, calculated for each stratum, in order of ID_STRATUM = 1, 2, ..., 9



### Subset FLUX_plotBYn array by stratum
# FLUX_plotBYn_strat(#): array with dim = # plots in this stratum x n; data are deltaC_ki values with units metric tons CO2/ha/y

FLUX_plotBYn_strat1 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==1),]
FLUX_plotBYn_strat2 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==2),]
FLUX_plotBYn_strat3 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==3),]
FLUX_plotBYn_strat4 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==4),]
FLUX_plotBYn_strat5 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==5),]
FLUX_plotBYn_strat6 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==6),]
FLUX_plotBYn_strat7 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==7),]
FLUX_plotBYn_strat8 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==8),]
FLUX_plotBYn_strat9 <- FLUX_plotBYn[which(FOREST_INPUT$ID_STRATUM==9),]
rm(FOREST_INPUT, FLUX_plotBYn)



### For each stratum, multiply each element of FLUX_plotBYn_strat(#) by that stratum's plot expansion factor
# FLUX_plotBYn_strat(#)_wtd: array with dim = # plots in this stratum x n; data are (deltaC_ki x omega_k) values with units metric tons CO2/y
# strata_expns_ha are omega_k

FLUX_plotBYn_strat1_wtd <- FLUX_plotBYn_strat1*strata_expns_ha[1]
FLUX_plotBYn_strat2_wtd <- FLUX_plotBYn_strat2*strata_expns_ha[2]
FLUX_plotBYn_strat3_wtd <- FLUX_plotBYn_strat3*strata_expns_ha[3]
FLUX_plotBYn_strat4_wtd <- FLUX_plotBYn_strat4*strata_expns_ha[4]
FLUX_plotBYn_strat5_wtd <- FLUX_plotBYn_strat5*strata_expns_ha[5]
FLUX_plotBYn_strat6_wtd <- FLUX_plotBYn_strat6*strata_expns_ha[6]
FLUX_plotBYn_strat7_wtd <- FLUX_plotBYn_strat7*strata_expns_ha[7]
FLUX_plotBYn_strat8_wtd <- FLUX_plotBYn_strat8*strata_expns_ha[8]
FLUX_plotBYn_strat9_wtd <- FLUX_plotBYn_strat9*strata_expns_ha[9]
rm(FLUX_plotBYn_strat1, FLUX_plotBYn_strat2, FLUX_plotBYn_strat3, FLUX_plotBYn_strat4, FLUX_plotBYn_strat5, FLUX_plotBYn_strat6, FLUX_plotBYn_strat7, FLUX_plotBYn_strat8, FLUX_plotBYn_strat9, strata_expns_ha)



### By stratum, take sum of area-weighted plot fluxes over all plots (do for each iterate i)
# wtd_sum_strat(#): vector with dim = n; data are sums of (deltaC_ki x omega_k) over all plots (k) in the indicated stratum (calculated for each i), units metric tons CO2/y

wtd_sum_strat1 <- apply(FLUX_plotBYn_strat1_wtd, 2, sum)
wtd_sum_strat2 <- apply(FLUX_plotBYn_strat2_wtd, 2, sum)
wtd_sum_strat3 <- apply(FLUX_plotBYn_strat3_wtd, 2, sum)
wtd_sum_strat4 <- apply(FLUX_plotBYn_strat4_wtd, 2, sum)
wtd_sum_strat5 <- apply(FLUX_plotBYn_strat5_wtd, 2, sum)
wtd_sum_strat6 <- apply(FLUX_plotBYn_strat6_wtd, 2, sum)
wtd_sum_strat7 <- apply(FLUX_plotBYn_strat7_wtd, 2, sum)
wtd_sum_strat8 <- apply(FLUX_plotBYn_strat8_wtd, 2, sum)
wtd_sum_strat9 <- apply(FLUX_plotBYn_strat9_wtd, 2, sum)

rm(FLUX_plotBYn_strat1_wtd, FLUX_plotBYn_strat2_wtd, FLUX_plotBYn_strat3_wtd, FLUX_plotBYn_strat4_wtd, FLUX_plotBYn_strat5_wtd, FLUX_plotBYn_strat6_wtd, FLUX_plotBYn_strat7_wtd, FLUX_plotBYn_strat8_wtd, FLUX_plotBYn_strat9_wtd)



### Calculate theta_i by summing the wtd sums for each stratum over all strata (do for each i)
# theta_i: vector with dim = n; data are sums of (deltaC_ki x omega_k) over all plots (k) (calculated for each i), units metric tons CO2/y

theta_i <- wtd_sum_strat1+wtd_sum_strat2+wtd_sum_strat3+wtd_sum_strat4+wtd_sum_strat5+wtd_sum_strat6+wtd_sum_strat7+wtd_sum_strat8+wtd_sum_strat9
rm(wtd_sum_strat1, wtd_sum_strat2, wtd_sum_strat3, wtd_sum_strat4, wtd_sum_strat5, wtd_sum_strat6, wtd_sum_strat7, wtd_sum_strat8, wtd_sum_strat9)






################################################################################################
### Calculate theta by taking average of all iterates (equation 2 of Ogle et al., 2010) ###
################################################################################################

# theta: average of theta_i over all n iterates ("m" iterates, in notation of Ogle et al., 2010)

theta <- mean(theta_i)			# mean stock change, metric tons CO2/y






################################################################################################
### Calculate V1 (equation 3 of Ogle et al., 2010) ###
################################################################################################

# V1: variance of the monte carlo replicates, accounting for uncertainty in model inputs and structure; units [metric tons CO2/y]^2
# V1 = (1/n-1) x sum over all n iterates of (theta_i - theta)^2


theta_diff_squared <- (theta_i-theta)^2
V1 <- (sum(theta_diff_squared))/(n-1)
rm(theta_diff_squared)






	
################################################################################################
### Convert important quantities from metric tons CO2 to MMT CO2 ###
################################################################################################

# Convert theta & theta_i values so that negative indicates sequestration

theta_i_MMTCO2 <- -1.*theta_i/1.e6		# iterates of annual stock change, metric tons CO2/y --> MMT CO2/y
theta_MMTCO2 <- -1.*theta/1.e6			# mean annual stock change, metric tons CO2/y --> MMT CO2/y
V1_MMTCO2 <- V1/(1.e12)					# modeling-based variance, [metric tons CO2/y]^2 --> [MMT CO2/y]^2
rm(n, theta, V1, theta_i)


print(c(" "),quote=FALSE)
print(c("V1, model-based variance for eastern Texas, [MMT CO2/y]^2 = ",V1_MMTCO2),quote=FALSE)	
rm(V1_MMTCO2)


print(c(" "),quote=FALSE)
print(c("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"),quote=FALSE)
print(c("!!! BELOW: NEGATIVE STOCK CHANGE VALUES INDICATE SEQUESTRATION !!!"),quote=FALSE)
print(c("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"),quote=FALSE)
print(c(" "),quote=FALSE)
print(c("Mean litter carbon stock change, MMT CO2/y = ", theta_MMTCO2),quote=FALSE)






################################################################################################
### Calculate 95% confidence interval for eastern Texas ###
################################################################################################

upper_bound <- as.numeric(quantile(theta_i_MMTCO2, c(0.975)))				# upper bound (97.5th percentile), units MMT CO2/y
lower_bound <- as.numeric(quantile(theta_i_MMTCO2, c(0.025)))				# lower bound (2.5th percentile), units MMT CO2/y

upper_error <- abs(upper_bound-theta_MMTCO2)
lower_error <- abs(theta_MMTCO2-lower_bound)

upper_relative <- 100.*abs((upper_error)/theta_MMTCO2)
lower_relative <- 100.*abs((lower_error)/theta_MMTCO2)

print(c(" "),quote=FALSE)
print(c("95% CI for eastern Texas"),quote=FALSE)
print(c("Upper bound (97.5th percentile), MMT CO2/y = ",upper_bound),quote=FALSE)	
print(c("Lower bound (2.5th percentile), MMT CO2/y = ",lower_bound),quote=FALSE)	
print(c("Upper bound, % = ",upper_relative),quote=FALSE)	
print(c("Lower bound, % = ",lower_relative),quote=FALSE)	

rm(upper_bound, lower_bound, upper_error, lower_error, theta_MMTCO2, theta_i_MMTCO2)






################################################################################################
### Scale eastern Texas FRF error to national level ###
################################################################################################

# Apply the percentage errors for eastern Texas to the total U.S. litter carbon stock change from the NGHGI (2018)

# Important variables:
# US_FLUX_MMTCO2y: litter carbon stock change for United States for FRF for 2016 (units: MMT CO2/y) -- this is a sequestration!
# upper_relative: percentage error in upper direction relative to mean flux (considering 95% CI) for eastern Texas
# lower_relative: percentage error in lower direction relative to mean flux (considering 95% CI) for eastern Texas


# Convert US flux so that sequestration is negative number
US_FLUX_MMTCO2y <- US_FLUX_MMTCO2y*(-1.)

print(c(" "),quote=FALSE)
print(c("Scaling eastern Texas percentage error to national level"),quote=FALSE)
print(c("Mean litter carbon stock change for U.S. FRF for 2016, MMT CO2/y (NGHGI 2018) = ",US_FLUX_MMTCO2y),quote=FALSE)


# Apply modeling error to U.S. flux
US_upper_error <- abs((upper_relative/100.)*US_FLUX_MMTCO2y)
US_lower_error <- abs((lower_relative/100.)*US_FLUX_MMTCO2y)

US_upper_bound <- US_FLUX_MMTCO2y+US_upper_error
US_lower_bound <- US_FLUX_MMTCO2y-US_lower_error
rm(US_upper_error, US_lower_error)

unc_contrib <- US_upper_bound-US_lower_bound

print(c("Upper bound (97.5th percentile), MMT CO2/y = ",US_upper_bound),quote=FALSE)
print(c("Lower bound (2.5th percentile), MMT CO2/y = ",US_lower_bound),quote=FALSE)
print(c("Contribution to uncertainty from litter modeling error, MMT CO2/y = ",unc_contrib),quote=FALSE)
rm(lower_relative, upper_relative, unc_contrib, US_FLUX_MMTCO2y, US_upper_bound, US_lower_bound)





