

# Version 1: 29 August 2019


# Monte Carlo analysis to estimate 95% confidence interval and model uncertainty associated 
# with soil carbon stock change. Additional details about the calculation method are available 
# in Section 2.3 of the Technical Appendix.


# INPUT DATA INCLUDES: 
# (1) Information from the FIA Database (USDA Forest Service, 2018) is used to identify the 
# coordinates (latitude and longitude) of a subset of plots in eastern Texas that contain 
# forest remaining forest (FRF) area. The stratum to which each of these plots belongs and 
# the total FRF area per stratum were also determined using FIA data.
# (2) The dominant soil order for each of the identified plots. This dataset was provided by 
# Steve Campbell at the USDA Natural Resources Conservation Service in Portland, OR, and is 
# derived from the SSURGO database (Soil Survey Staff, 2019).
# (3) Mean soil carbon stock (metric tons C/ha) by soil order. See Section 2.3 of Technical 
# Appendix for information about how these values were derived from summary statistics reported 
# by Domke et al. (2017).
# (4) National-mean soil carbon sequestration rate for FRF for 2016, based on data in NGHGI (2018).


# OUTPUT PRINTED TO SCREEN INCLUDES:
# Model-based variance for the eastern Texas analysis region
# Mean soil carbon stock change for eastern Texas
# 95% confidence interval for eastern Texas soil carbon stock change
# 95% confidence interval for United States soil carbon stock change
# Contribution to uncertainty from soil modeling error




# PROGRAM NOTES:

# This script requires installation of the R package "compositions" (van den Boogaart, 2018). 
# The function rlnorm.rplus in this package is used.

# ID_STRATUM key for input file SOIL_PLOTS_FRF.csv (based on estimation unit and canopy cover bin):
# 1 - STRATUM_CN = 540237787126144 indicates NFS 0-98% canopy cover (NFS bin 1)
# 2 - STRATUM_CN = 540237788126144 indicates NFS 99-100% canopy cover (NFS bin 2)
# 3 - STRATUM_CN = 540237779126144 indicates SE 0-10% canopy cover (SE bin 1)
# 4 - STRATUM_CN = 540237780126144 indicates SE 11-47% canopy cover (SE bin 2)
# 5 - STRATUM_CN = 540237781126144 indicates SE 48-84% canopy cover (SE bin 3)
# 6 - STRATUM_CN = 540237782126144 indicates SE 85-100% canopy cover (SE bin 4)
# 7 - STRATUM_CN = 540237783126144 indicates NE 0-47% canopy cover (NE bin 1)
# 8 - STRATUM_CN = 540237785126144 indicates NE 48-84% canopy cover (NE bin 2)
# 9 - STRATUM_CN = 540237786126144 indicates NE 85-100% canopy cover (NE bin 3)
# NFS = National Forest Service land; NE = Northeast Texas, excluding NFS land; SE = Southeast Texas, excluding NFS land
# STRATUM_CN corresponds to identifier used in FIA Database (USDA Forest Service, 2018).

# Area (ha) of FRF in each stratum (calculated using data from FIA Database - USDA Forest Service, 2018):
# STRATUM 1: 88,317
# STRATUM 2: 161,101
# STRATUM 3: 18,625
# STRATUM 4: 211,945
# STRATUM 5: 445,847
# STRATUM 6: 1,783,418
# STRATUM 7: 144,158
# STRATUM 8: 450,279
# STRATUM 9: 1,449,369

# Applies lognormal distribution for the soil carbon stocks.

# National-mean soil carbon sequestration rate for FRF for 2016, based on data in NGHGI (2018):
# (1) 36.9 MMT C/y is the national annual carbon sequestration for soil 
# (mineral + organic, excluding drained organic soils) on FRF for 2016 (Table 6.11 of NGHGI, 2018)
# (2) 272,260,000 ha is the national FRF area in 2016 (Table 6.12 of NGHGI, 2018)
# Divide (1) by (2) to get national-mean soil carbon sequestration rate for FRF 
# = (36,900,000 metric tons C/y) / (272,260,000 ha) = 0.136 metric tons C/ha/y

# The mean soil carbon stock change output from this script should be around 0.646 MMT C/y 
# (sequestered) based on: (1) there are 4,753,058 ha FRF in eastern Texas 
# (calculated using data from FIA Database - USDA Forest Service, 2018) 
# and (2) the national-mean sequestration rate for FRF is 0.136 metric tons C/ha/y.

# Equations 1-3 of Ogle et al. (2010) are applied in this script. Equation 1 is used to calculate 
# the annual change in soil carbon stock for each iterate. Equation 2 is used to calculate the mean 
# annual change in soil carbon stock over all iterates. The 95% confidence interval for eastern Texas 
# is estimated using these results. Equation 3 of Ogle et al. (2010) is used to calculate the variance 
# associated with model uncertainty. The sampling error is not calculated as all plots are forced 
# to have the national mean sequestration rate. The model variance is used to combine uncertainties 
# for the forest litter, soil, and biomass pools (see Section 2.1 of the Technical Appendix).





# REFERENCES:

# Domke, G. M., Perry, C. H., Walters, B. F., Nave, L. E., Woodall, C. W., & Swantson, C., W. (2017). Toward inventory-based estimate of soil organic carbon in forests of the United States. Ecological Applications, 27(4), 1223-1235.

# Ogle, S. M., Breidt, F. J., Easter, M., Williams, S., Killian, K., and Paustian, K. (2010). Scale and uncertainty in modeled soil organic carbon stock changes for US croplands using a process-based model. Global Change Biology 16, 810-822, doi: 10.1111/j.1365-2486.2009.01951.x.

# Soil Survey Staff, Natural Resources Conservation Service, United States Department of Agriculture. Soil Survey Geographic (SSURGO) Database. Accessed 2019. Prepared data from SSURGO Database was provided by Steve Campbell at USDA Natural Resources Conservation Service in Portland, OR.

# United States Environmental Protection Agency. (2018). Inventory of U.S. Greenhouse Gas Emissions and Sinks: 1990-2016. Washington, DC.

# USDA Forest Service (2018). Forest Inventory and Analysis National Program: FIA Data Mart. Washington, DC. Available online at: https://apps.fs.usda.gov/fia/datamart/datamart.html. Accessed 25 August 2018. This reference is abbreviated in this script as NGHGI (2018).

# van den Boogaart, K. G., Tolosana-Delgado, R., & Bren, M. (2018). compositions: Compositional Data Analysis, (R package version 1.40-2). https://CRAN.R-project.org/package=compositions







################################################################################################
### Input data ###
################################################################################################

library(compositions)			# Contains rlnorm.rplus function

### Input plot data
SOIL_FRF_filename <- "SOIL_PLOTS_FRF.csv"		# 1 row for each plot, with columns: PLT_CN, ID_STRATUM, SOIL_ORDER
FRF_INPUT <- read.table(SOIL_FRF_filename,header=TRUE,sep=",",stringsAsFactors=FALSE)
num_FRF_plots <- nrow(FRF_INPUT)
rm(SOIL_FRF_filename)



### Define parameters
n <- 50000							# Number of draws
cov_as_frac_of_var <- 0.999			# Covariance between previous period and next period (previous period + 1 year) soil carbon stocks is set as a fraction of the stock variance
US_FLUX_MMTCy <- 36.9				# MMT C/y soil carbon stock change for United States for FRF for 2016, from Table 6-11 of NGHGI (2018); this is a sequestration
FRF_HA_STRATUM <- c(88317, 161101, 18625, 211945, 445847, 1783418, 144158, 450279, 1449369)					# Area (ha) of FRF in each stratum, in order of ID_STRATUM 1, 2, ..., 9

print(c("n =",n),quote=FALSE)
print(c("covariance = ",cov_as_frac_of_var," x variance"),quote=FALSE)






################################################################################################
### Calculate expansion factors for plots by stratum ###
################################################################################################

# Expansion factor for a given stratum indicates the # of hectares of FRF represented by each FRF-containing plot in that stratum that is used as input

### Calculate number of FRF-containing plots in each stratum
num_plots_strat <- vector(mode="numeric",length=9)
num_plots_strat[1] <- length(which(FRF_INPUT$ID_STRATUM==1))
num_plots_strat[2] <- length(which(FRF_INPUT$ID_STRATUM==2))
num_plots_strat[3] <- length(which(FRF_INPUT$ID_STRATUM==3))
num_plots_strat[4] <- length(which(FRF_INPUT$ID_STRATUM==4))
num_plots_strat[5] <- length(which(FRF_INPUT$ID_STRATUM==5))
num_plots_strat[6] <- length(which(FRF_INPUT$ID_STRATUM==6))
num_plots_strat[7] <- length(which(FRF_INPUT$ID_STRATUM==7))
num_plots_strat[8] <- length(which(FRF_INPUT$ID_STRATUM==8))
num_plots_strat[9] <- length(which(FRF_INPUT$ID_STRATUM==9))


### For each stratum, calculate expansion factor by dividing # of ha of FRF in that stratum by # of FRF-containing plots in that stratum
strata_expns_ha <- FRF_HA_STRATUM/num_plots_strat		# In order of ID_STRATUM 1, 2, ..., 9; # ha represented by each plot in the indicated stratum	
rm(FRF_HA_STRATUM, num_plots_strat)






################################################################################################
### Assign soil order statistics ###
################################################################################################

# Soil order statistics for those soil types present on FRF-containing analysis plots in eastern Texas

### For previous period, assign mean soil carbon stock (metric tons C/ha) based on soil order
# See Section 2.3 of Technical Appendix for information about the derivation of these values from statistics reported by Domke et al. (2017)
soil_mean_previous <- vector(mode="numeric",length=num_FRF_plots)
soil_mean_previous[which(FRF_INPUT$SOIL_ORDER==0)] <- 5.0656 		# All
soil_mean_previous[which(FRF_INPUT$SOIL_ORDER==1)] <- 4.7368		# Alfisols 
soil_mean_previous[which(FRF_INPUT$SOIL_ORDER==3)] <- 4.6130 		# Entisols
soil_mean_previous[which(FRF_INPUT$SOIL_ORDER==4)] <- 5.1886 		# Inceptisols
soil_mean_previous[which(FRF_INPUT$SOIL_ORDER==5)] <- 5.0262 		# Mollisols
soil_mean_previous[which(FRF_INPUT$SOIL_ORDER==6)] <- 4.6480		# Ultisols
soil_mean_previous[which(FRF_INPUT$SOIL_ORDER==7)] <- 4.9752		# Vertisols


### For next period (previous period + 1 year), assign mean soil carbon stock (metric tons C/ha) that is equal to the previous period stock plus 0.136 metric tons C/ha. (Carbon stock values given in form needed for rlnorm.rplus function.) The result is that, assuming a 1-year time step, the sequestration rate for each plot will be identical to the national-average sequestration rate of 0.136 metric tons C/ha/y.
soil_mean_next <- vector(mode="numeric",length=num_FRF_plots)
soil_mean_next[which(FRF_INPUT$SOIL_ORDER==0)] <- 5.0663 		# All
soil_mean_next[which(FRF_INPUT$SOIL_ORDER==1)] <- 4.7379			# Alfisols 
soil_mean_next[which(FRF_INPUT$SOIL_ORDER==3)] <- 4.6142 		# Entisols
soil_mean_next[which(FRF_INPUT$SOIL_ORDER==4)] <- 5.1893 		# Inceptisols
soil_mean_next[which(FRF_INPUT$SOIL_ORDER==5)] <- 5.0270 		# Mollisols
soil_mean_next[which(FRF_INPUT$SOIL_ORDER==6)] <- 4.6492			# Ultisols
soil_mean_next[which(FRF_INPUT$SOIL_ORDER==7)] <- 4.9761			# Vertisols


### Assign variance for soil carbon stock [metric tons C/ha]^2 based on soil order
soil_var <- vector(mode="numeric",length=num_FRF_plots)
soil_var[which(FRF_INPUT$SOIL_ORDER==0)] <- 0.36818 				# All
soil_var[which(FRF_INPUT$SOIL_ORDER==1)] <- 0.22147					# Alfisols 
soil_var[which(FRF_INPUT$SOIL_ORDER==3)] <- 0.17164 				# Entisols
soil_var[which(FRF_INPUT$SOIL_ORDER==4)] <- 0.29165 				# Inceptisols
soil_var[which(FRF_INPUT$SOIL_ORDER==5)] <- 0.12979 				# Mollisols
soil_var[which(FRF_INPUT$SOIL_ORDER==6)] <- 0.19903					# Ultisols
soil_var[which(FRF_INPUT$SOIL_ORDER==7)] <- 0.005976				# Vertisols


FRF_INPUT$soil_mean_previous <- soil_mean_previous
FRF_INPUT$soil_mean_next <- soil_mean_next
FRF_INPUT$soil_var <- soil_var
rm(soil_mean_previous, soil_mean_next, soil_var)




################################################################################################
### Plot-level calculations ###
################################################################################################

### For each plot:
# (1) Apply rlnorm.rplus given prescribed means and variances. Covariance of stocks for the two periods is calculated as a fraction of the prescribed variance for the given soil order. Result is n values for previous period soil carbon stock and n values for next period (previous period + 1 year) soil carbon stock, with carbon stock units of metric tons C/ha.
# (2) For each of the n pairs, take next period stock minus previous period stock to get n annual stock change (flux) values with units of metric tons C/ha/y. Assumes a 1-year time step. Positive values indicate sequestration.


# Make array for storing the output with dimensions: # plots x n
FLUX_plotBYn <- array(NA, dim=c(num_FRF_plots, n))


set.seed(1510.1992)

for(i in 1:num_FRF_plots){	
	means=c(FRF_INPUT$soil_mean_previous[i], FRF_INPUT$soil_mean_next[i])		# Vector of means used as input for the rlnorm function, metric tons C/ha
	stock_variance <- FRF_INPUT$soil_var[i]										# Stock variance for this plot, based on soil order, [metric tons C/ha]^2
	stock_covariance <- cov_as_frac_of_var*FRF_INPUT$soil_var[i]					# Covariance for this plot, calculated as a fraction of the stock variance, [metric tons C/ha]^2
	sigma <- matrix(c(stock_variance,stock_covariance,stock_covariance,stock_variance), nrow=2, ncol=2)		# Variance/covariance matrix used as input for the rlnorm.rplus function
	plot_stocks <- rlnorm.rplus(n, means, sigma)								# Result: array with dims = n x 2 (1 - previous period stock, 2 - next period stock); stock units of metric tons C/ha
	n_flux <- (plot_stocks[,2]-plot_stocks[,1])									# Vector with dim = n, flux units: metric tons C/ha/y
	FLUX_plotBYn[i,] <- n_flux													# Assign n_flux for this plot to FLUX_plotBYn array, flux units: metric tons C/ha/y
	rm(means, stock_variance, stock_covariance, sigma, plot_stocks, n_flux)
}
rm(i, num_FRF_plots, cov_as_frac_of_var)


if(any(is.na(FLUX_plotBYn))){
	print(c("ERROR: Missing values in FLUX_plotBYn"),quote=FALSE)	
}






################################################################################################
### Calculate theta for each iteration (equation 1 of Ogle et al., 2010) ###
################################################################################################

# For the modeling uncertainty calculation, notation follows that of equations 1-3 in Ogle et al. (2010).
# theta_i: change in soil carbon stock for iterate i
# omega_k: area weight assigned to each plot k
# deltaC_ki: change in soil carbon stock for the kth plot for iterate i

# theta_i = sum over each plot k of (omega_k x deltaC_ki) 

# Input data:
# FLUX_plotBYn: array of fluxes (metric tons C/ha/y), dim = # plots x n
# FRF_INPUT: each row corresponds to a plot; has 2 columns - ID_STRATUM and SOIL_ORDER
# strata_expns_ha: # ha represented by each plot, calculated for each stratum, in order of ID_STRATUM = 1, 2, ..., 9




### Subset FLUX_plotBYn array by stratum
# FLUX_plotBYn_strat(#): array with dim = # plots in this stratum x n; data are deltaC_ki values with units metric tons C/ha/y

FLUX_plotBYn_strat1 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==1),]
FLUX_plotBYn_strat2 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==2),]
FLUX_plotBYn_strat3 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==3),]
FLUX_plotBYn_strat4 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==4),]
FLUX_plotBYn_strat5 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==5),]
FLUX_plotBYn_strat6 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==6),]
FLUX_plotBYn_strat7 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==7),]
FLUX_plotBYn_strat8 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==8),]
FLUX_plotBYn_strat9 <- FLUX_plotBYn[which(FRF_INPUT$ID_STRATUM==9),]
rm(FRF_INPUT, FLUX_plotBYn)



### For each stratum, multiply each element of FLUX_plotBYn_strat(#) by that stratum's plot expansion factor
# FLUX_plotBYn_strat(#)_wtd: array with dim = # plots in this stratum x n; data are (deltaC_ki x omega_k) values with units metric tons C/y
# strata_expns_ha are omega_k

FLUX_plotBYn_strat1_wtd <- FLUX_plotBYn_strat1*strata_expns_ha[1]
FLUX_plotBYn_strat2_wtd <- FLUX_plotBYn_strat2*strata_expns_ha[2]
FLUX_plotBYn_strat3_wtd <- FLUX_plotBYn_strat3*strata_expns_ha[3]
FLUX_plotBYn_strat4_wtd <- FLUX_plotBYn_strat4*strata_expns_ha[4]
FLUX_plotBYn_strat5_wtd <- FLUX_plotBYn_strat5*strata_expns_ha[5]
FLUX_plotBYn_strat6_wtd <- FLUX_plotBYn_strat6*strata_expns_ha[6]
FLUX_plotBYn_strat7_wtd <- FLUX_plotBYn_strat7*strata_expns_ha[7]
FLUX_plotBYn_strat8_wtd <- FLUX_plotBYn_strat8*strata_expns_ha[8]
FLUX_plotBYn_strat9_wtd <- FLUX_plotBYn_strat9*strata_expns_ha[9]
rm(FLUX_plotBYn_strat1, FLUX_plotBYn_strat2, FLUX_plotBYn_strat3, FLUX_plotBYn_strat4, FLUX_plotBYn_strat5, FLUX_plotBYn_strat6, FLUX_plotBYn_strat7, FLUX_plotBYn_strat8, FLUX_plotBYn_strat9, strata_expns_ha)



### By stratum, take sum of area-weighted plot fluxes over all plots (do for each iterate i)
# wtd_sum_strat(#): vector with dim = n; data are sums of (deltaC_ki x omega_k) over all plots (k) in the indicated stratum (calculated for each i), units metric tons C/y

wtd_sum_strat1 <- apply(FLUX_plotBYn_strat1_wtd, 2, sum)
wtd_sum_strat2 <- apply(FLUX_plotBYn_strat2_wtd, 2, sum)
wtd_sum_strat3 <- apply(FLUX_plotBYn_strat3_wtd, 2, sum)
wtd_sum_strat4 <- apply(FLUX_plotBYn_strat4_wtd, 2, sum)
wtd_sum_strat5 <- apply(FLUX_plotBYn_strat5_wtd, 2, sum)
wtd_sum_strat6 <- apply(FLUX_plotBYn_strat6_wtd, 2, sum)
wtd_sum_strat7 <- apply(FLUX_plotBYn_strat7_wtd, 2, sum)
wtd_sum_strat8 <- apply(FLUX_plotBYn_strat8_wtd, 2, sum)
wtd_sum_strat9 <- apply(FLUX_plotBYn_strat9_wtd, 2, sum)

rm(FLUX_plotBYn_strat1_wtd, FLUX_plotBYn_strat2_wtd, FLUX_plotBYn_strat3_wtd, FLUX_plotBYn_strat4_wtd, FLUX_plotBYn_strat5_wtd, FLUX_plotBYn_strat6_wtd, FLUX_plotBYn_strat7_wtd, FLUX_plotBYn_strat8_wtd, FLUX_plotBYn_strat9_wtd)



### Calculate theta_i by summing the wtd sums for each stratum over all strata (do for each i)
# theta_i: vector with dim = n; data are sums of (deltaC_ki x omega_k) over all plots (k) (calculated for each i), units metric tons C/y

theta_i <- wtd_sum_strat1+wtd_sum_strat2+wtd_sum_strat3+wtd_sum_strat4+wtd_sum_strat5+wtd_sum_strat6+wtd_sum_strat7+wtd_sum_strat8+wtd_sum_strat9
rm(wtd_sum_strat1, wtd_sum_strat2, wtd_sum_strat3, wtd_sum_strat4, wtd_sum_strat5, wtd_sum_strat6, wtd_sum_strat7, wtd_sum_strat8, wtd_sum_strat9)






################################################################################################
### Calculate theta by taking average of all iterates (equation 2 of Ogle et al., 2010) ###
################################################################################################

# theta: average of theta_i over all n iterates ("m" iterates, in notation of Ogle et al., 2010)

theta <- mean(theta_i)			# mean stock change, metric tons C/y







################################################################################################
### Calculate V1 (equation 3 of Ogle et al., 2010) ###
################################################################################################

# V1: variance of the monte carlo replicates, accounting for uncertainty in model inputs and structure; units [metric tons C/ha/y]^2
# V1 = (1/n-1) x sum over all n iterates of (theta_i - theta)^2


theta_diff_squared <- (theta_i-theta)^2
V1 <- (sum(theta_diff_squared))/(n-1)
rm(theta_diff_squared)






################################################################################################
### Convert important quantities from metric tons C to MMT CO2 ###
################################################################################################

# Convert theta & theta_i values so that negative indicates sequestration

theta_i_MMTCO2 <- -1.*theta_i*(44./12.)/1.e6	# iterates of annual stock change, metric tons C/y --> MMT CO2/y
theta_MMTCO2 <- -1.*theta*(44./12.)/1.e6		# mean annual stock change, metric tons C/y --> MMT CO2/y
V1_MMTCO2 <- V1*((44./12.)^2)/(1.e12)			# modeling-based variance, [metric tons C/y]^2 --> [MMT CO2/y]^2
rm(n, theta, theta_i, V1)


print(c(" "),quote=FALSE)
print(c("V1, model-based variance for eastern Texas, [MMT CO2/y]^2 = ",V1_MMTCO2),quote=FALSE)	
rm(V1_MMTCO2)

print(c(" "),quote=FALSE)
print(c("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"),quote=FALSE)
print(c("!!! BELOW: NEGATIVE STOCK CHANGE VALUES INDICATE SEQUESTRATION !!!"),quote=FALSE)
print(c("!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"),quote=FALSE)
print(c(" "),quote=FALSE)
print(c("Mean soil carbon stock change, MMT CO2/y = ", theta_MMTCO2),quote=FALSE)





################################################################################################
### Calculate 95% confidence interval for eastern Texas ###
################################################################################################

upper_bound <- as.numeric(quantile(theta_i_MMTCO2, c(0.975)))				# upper bound (97.5th percentile), units MMT CO2/y
lower_bound <- as.numeric(quantile(theta_i_MMTCO2, c(0.025)))				# lower bound (2.5th percentile), units MMT CO2/y

upper_error <- abs(upper_bound-theta_MMTCO2)
lower_error <- abs(theta_MMTCO2-lower_bound)

upper_relative <- 100.*abs((upper_error)/theta_MMTCO2)
lower_relative <- 100.*abs((lower_error)/theta_MMTCO2)

print(c(" "),quote=FALSE)
print(c("95% CI for eastern Texas"),quote=FALSE)
print(c("Upper bound (97.5th percentile), MMT CO2/y = ",upper_bound),quote=FALSE)	
print(c("Lower bound (2.5th percentile), MMT CO2/y = ",lower_bound),quote=FALSE)	
print(c("Upper bound, % = ",upper_relative),quote=FALSE)	
print(c("Lower bound, % = ",lower_relative),quote=FALSE)	


rm(upper_bound, lower_bound, upper_error, lower_error, theta_MMTCO2, theta_i_MMTCO2)






################################################################################################
### Scale eastern Texas FRF error to national level ###
################################################################################################

# Apply the percentage errors for eastern Texas to the total U.S. soil carbon stock change from the NGHGI (2018)

# Important variables:
# US_FLUX_MMTCy: soil carbon stock change for United States for FRF for 2016 (units: MMT CO2/y) -- this is a sequestration!
# upper_relative: percentage error in upper direction relative to mean flux (considering 95% CI) for eastern Texas
# lower_relative: percentage error in lower direction relative to mean flux (considering 95% CI) for eastern Texas


# Convert US flux so that sequestration is negative number & convert to MMT CO2
US_FLUX_MMTCO2y <- US_FLUX_MMTCy*(-1.)*(44./12.)

print(c(" "),quote=FALSE)
print(c("Scaling eastern Texas percentage error to national level"),quote=FALSE)
print(c("Mean soil carbon stock change for U.S. FRF for 2016, MMT CO2/y (NGHGI 2018) = ",US_FLUX_MMTCO2y),quote=FALSE)


# Apply modeling error to U.S. flux
US_upper_error <- abs((upper_relative/100.)*US_FLUX_MMTCO2y)
US_lower_error <- abs((lower_relative/100.)*US_FLUX_MMTCO2y)

US_upper_bound <- US_FLUX_MMTCO2y+US_upper_error
US_lower_bound <- US_FLUX_MMTCO2y-US_lower_error
rm(US_upper_error, US_lower_error)

unc_contrib <- US_upper_bound-US_lower_bound

print(c("Upper bound (97.5th percentile), MMT CO2/y = ",US_upper_bound),quote=FALSE)
print(c("Lower bound (2.5th percentile), MMT CO2/y = ",US_lower_bound),quote=FALSE)
print(c("Contribution to uncertainty from soil modeling error, MMT CO2/y = ",unc_contrib),quote=FALSE)
rm(lower_relative, upper_relative, unc_contrib, US_FLUX_MMTCy, US_FLUX_MMTCO2y, US_upper_bound, US_lower_bound)






